.. Sage documentation master file, created by sphinx-quickstart on
.. Thu Aug 21 20:15:55 2008. You can adapt this file completely to
.. your liking, but it should at least contain the root `toctree`
.. directive.

.. _faq:

===================
Welcome to Sage FAQ
===================

This work is licensed under a `Creative Commons Attribution-Share Alike
3.0 License`__.  With grateful thanks, we acknowledge it as being
originally compiled by Minh Van Nguyen.

__ http://creativecommons.org/licenses/by-sa/3.0/

.. toctree::
   :maxdepth: 2

   faq-general
   faq-usage
   faq-contribute

Indices and tables
==================

* :ref:`genindex`
* :ref:`search`
